@@ -6,9 +6,10 @@ use vars qw($m_hrActions $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Actions::EXPORT = qw(loadActions saveActions $m_hrActions);
 use MySQL::Admin::Config;
 @MySQL::Admin::Actions::ISA     = qw( Exporter MySQL::Admin::Config);
-$MySQL::Admin::Actions::VERSION = '0.5';
-$DefaultClass                   = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
-$defaultconfig                  = '%CONFIG%';
+$MySQL::Admin::Actions::VERSION = '0.51';
+$DefaultClass                   = 'MySQL::Admin::Actions'
+    unless defined $MySQL::Admin::Actions::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -52,9 +53,8 @@ loadActions() saveActions() $m_hrActions
 
 =cut
 
-sub new
-{
-    my ($class, @initializer) = @_;
+sub new {
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
@@ -64,21 +64,19 @@ sub new
 
 =cut
 
-sub loadActions
-{
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if (-e $do) {do $do;}
+sub loadActions {
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if ( -e $do ) { do $do; }
 }
 
 =head2 saveActions
 
 =cut
 
-sub saveActions
-{
-    my ($self, @p) = getSelf(@_);
-    $self->SUPER::saveConfig(@p, $m_hrActions, 'actions');
+sub saveActions {
+    my ( $self, @p ) = getSelf(@_);
+    $self->SUPER::saveConfig( @p, $m_hrActions, 'actions' );
 }
 
 =head1 Private
@@ -87,12 +85,17 @@ sub saveActions
 
 =cut
 
-sub getSelf
-{
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'MySQL::Admin::Actions');
-    return (defined($_[0]) && (ref($_[0]) eq 'MySQL::Admin::Actions' || UNIVERSAL::isa($_[0], 'MySQL::Admin::Actions')))
-      ? @_
-      : ($MySQL::Admin::Actions::DefaultClass->new, @_);
+sub getSelf {
+    return @_
+        if defined( $_[0] )
+            && ( !ref( $_[0] ) )
+            && ( $_[0] eq 'MySQL::Admin::Actions' );
+    return ( defined( $_[0] )
+                 && ( ref( $_[0] ) eq 'MySQL::Admin::Actions'
+                      || UNIVERSAL::isa( $_[0], 'MySQL::Admin::Actions' ) )
+        )
+        ? @_
+        : ( $MySQL::Admin::Actions::DefaultClass->new, @_ );
 }
 
 =head2 see Also
